@@ -112,7 +112,7 @@ class BitmexOrder:
         self.props = {}
         for symbol in symbols:
             self.props[symbol] = {
-                'stoploss_id': '', 'entry': .0, 'SL': .0, 'TP': .0, 'open': False, 'qty': 0}
+                'stoploss_id': '', 'entry': .0, 'SL': .0, 'TP': .0, 'open': False, 'wait_stop': False, 'qty': 0}
 
     def check_open_bot_order(self, symbol, entry, sl):
         settings = pickle.load(open(self._settings_path, 'rb'))
