@@ -167,7 +167,7 @@ class Lotus:
 
     def run(self):
         # Main loop
-        self.order = BitmexOrder(
+        self.order = BitmexOrder(self.symbols,
             self.client, self.settings, self._settings_path)
         self.process_signals(start=True)
         while True:
